/*
 * _NET_WM_ICON helpers for slide puzzle game
 * Copyright © 2022 Nick Bowler
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

#ifndef RRACE_EWMHICON_H_
#define RRACE_EWMHICON_H_

/*
 * Define X_DISPLAY_MISSING to allow building without X11 (for test purposes)
 */
#if !X_DISPLAY_MISSING
#  include <X11/Intrinsic.h>
#else

/* Stub types to allow compilation */
typedef struct {
	unsigned long pixel;
	unsigned short red, green, blue;
} XColor;

#endif

/*
 * Size of generated EWMH icon data (nelements argument to XChangeProperty).
 */
#define EWMH_ICON_NELEM (2+16*16 + 2+24*24 + 2+32*32 + 2+48*48)

/*
 * Generate EWMH icon data based on a sequence of tile colours.  Internally,
 * this calls icon_tile16 and friends to draw each of the icon patterns.
 *
 * The sequence specifies the colour of all 9 icon tiles, beginning from the
 * top left in row-major order.  Each value specifies three offsets into
 * the provided colour map, encoded in the same manner as icon_tile16 et al.
 *
 * Returns a newly-allocated buffer which is suitable for use directly with
 * XChangeProperty, and should be freed by the caller.
 *
 * If allocation fails, a null pointer is returned.
 */
void *ewmh_icon_generate(const unsigned long *seq, const XColor *map);

#if !X_DISPLAY_MISSING
/*
 * Check if the root window indicates support for EWMH icons.  Returns 1 if
 * supported, or 0 otherwise.
 */
int ewmh_probe_wm_icon(Widget shell);
#endif

#endif
